@@ -156,17 +156,29 @@ class HTTP(cli.SubCommand):
             forceresolve_arg(),
         ),
         timeout_arg(),
+        cli.Argument(
+            '-H', '--header',
+            action='append',
+            default=[],
+            help='Extra  header to include in the request when sending HTTP '
+                 'to a server.'
+        ),
         cli.Argument(
             '-i', '--include-headers',
             action='store_true',
             help='Include protocol response headers in the output.'
         ),
+        cli.Argument(
+            '-b', '--binary-output',
+            action='store_true',
+            help='Treat response as binary.'
+        ),
         port_arg(),
         cli.Argument('verb'),
         cli.Argument('url'),
         cli.Argument(
             'fields',
-            metavar='[?]NAME=VALUE',
+            metavar='[?|@]NAME=VALUE',
             default=[],
             nargs='*'
         )
@@ -204,37 +216,53 @@ class HTTP(cli.SubCommand):
             if k[0] == '?':
                 query.append((k[1:], v))
             elif k[0] == '@':
-                files.append((k[1:], open(v)))
+                files.append((k[1:], open(v, mode='rb')))
             else:
                 fields.append((k, v))
 
-        response = http.request(
+        # Request headers
+        reqheaders = {
+            k.strip(): v.strip() for k, v in
+            [h.split(':') for h in args.header]
+        }
+        resp = http.request(
             args.verb.upper(),
             f'http://{addr}{port}{path_}',
             query=query,
             form=body if body else fields,
             files=files,
+            headers=reqheaders
         )
 
+        # Response headers
+        respheaders = [
+            f'{resp.status_code} {resp.reason} '
+            f'HTTP/{resp.raw.version / 10:.1f}'
+        ]
+        respheaders += [f'{k}: {v}' for k, v in resp.headers.items()]
+        if args.include_headers:
+            output('\n'.join(respheaders), end='\n\n')
+
         # Handle exception
-        if response.status_code >= 400:
-            error(response.text, end='')
+        if resp.status_code >= 400:
+            error(resp.text, end='')
             return 1
 
         # Binary output
-        if response.headers.get('content-type'):
+        binary = False
+        if args.binary_output:
+            binary = True
+
+        elif resp.headers.get('content-type'):
             for c in BINARY_CONTENTTYPES:
-                if c.match(response.headers['content-type']):
-                    stdout.buffer.write(response.content)
-                    return
+                if c.match(resp.headers['content-type']):
+                    binary = True
+                    break
 
-        if args.include_headers:
-            output(
-                '\n'.join([f'{k}: {v}' for k, v in response.headers.items()]),
-                end='\n\n'
-            )
-
-        output(response.text, end='')
+        if binary:
+            stdout.buffer.write(resp.content)
+        else:
+            output(resp.text, end='')
 
 
 class UNS(cli.Root):
